import { Emitter } from './Emitter';
/**
 * Returns a proxied object and an emitter which will emit 'added', 'changed' and 'deleted' events
 * whenever changes are made to the returned proxy. Useful for a simple state store.
 *
 ```typescript
 * import { Observable } from 'goodish'
 * const [o, bus] = Observable({ a: 1 })
 *
 * bus.on('added', (path: string[], value: any) => {})
 * bus.on('deleted', (path: string[]) => {})
 * bus.on('changed', (path: string[], value: any) => {})
 *
 * o.b = 2          // Fires 'added' event
 * o.a = 2          // Fires 'changed' event
 * delete o.a       // Fires 'deleted' event
 * o.a = undefined  // Fires 'deleted' event
 * ```
 *
 * @param value
 *
 */
export declare function Observable<T extends (object | any[])>(value: T): [T, Emitter];
